summaryrefslogtreecommitdiffstats
path: root/src/hardware.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/hardware.cpp')
-rw-r--r--src/hardware.cpp14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/hardware.cpp b/src/hardware.cpp
index 54d5027..f4efedd 100644
--- a/src/hardware.cpp
+++ b/src/hardware.cpp
@@ -200,9 +200,9 @@ void HardwareInfo::processKeyPressEvent(unsigned int keycode, TDEEventDevice* ed
if (((edevice->eventType() == TDEEventDeviceType::ACPIPowerButton) || (edevice->eventType() == TDEEventDeviceType::ACPIOtherInput))
&& (keycode == KEY_POWER)) {
TQTimer::singleShot(50, this, TQT_SLOT(emitPowerButtonPressed()));
- } else if (((edevice->eventType() == TDEEventDeviceType::ACPISleepButton) || (edevice->eventType() == TDEEventDeviceType::ACPIOtherInput))
+ } else if (((edevice->eventType() == TDEEventDeviceType::ACPISuspendButton) || (edevice->eventType() == TDEEventDeviceType::ACPIOtherInput))
&& (keycode == KEY_SLEEP)) {
- TQTimer::singleShot(50, this, TQT_SLOT(emitSleepButtonPressed()));
+ TQTimer::singleShot(50, this, TQT_SLOT(emitSuspendButtonPressed()));
} else if (((edevice->eventType() == TDEEventDeviceType::ACPISuspendButton) || (edevice->eventType() == TDEEventDeviceType::ACPIOtherInput))
&& (keycode == KEY_SUSPEND)) {
TQTimer::singleShot(50, this, TQT_SLOT(emitS2diskButtonPressed()));
@@ -268,7 +268,7 @@ bool HardwareInfo::checkIfHandleDevice ( TQString _udi, int *type) {
*type = LID;
} else if (edevice->eventType() == TDEEventDeviceType::ACPIPowerButton) {
*type = BUTTON_POWER;
- } else if (edevice->eventType() == TDEEventDeviceType::ACPISleepButton) {
+ } else if (edevice->eventType() == TDEEventDeviceType::ACPISuspendButton) {
*type = BUTTON_SLEEP;
} else {
ret = false;
@@ -842,9 +842,9 @@ bool HardwareInfo::suspend( suspend_type suspend ) {
}
} else {
if ( !suspend_states.suspend2ram )
- kdDebug() << "The machine does not support Sleep mode." << endl;
+ kdDebug() << "The machine does not support Suspend mode." << endl;
else
- kdWarning() << "Policy forbid user to trigger Sleep mode" << endl;
+ kdWarning() << "Policy forbid user to trigger Suspend mode" << endl;
return false;
}
@@ -1097,9 +1097,9 @@ void HardwareInfo::emitPowerButtonPressed() {
}
/*!
* Function to emit the signal for the Sleep button.
*/
-void HardwareInfo::emitSleepButtonPressed() {
+void HardwareInfo::emitSuspendButtonPressed() {
if (sessionIsActive) {
emit sleepButtonPressed();
} else {
@@ -1097,9 +1097,9 @@ void HardwareInfo::emitPowerButtonPressed() {
}
/*!
- * Function to emit the signal for the Sleep button.
+ * Function to emit the signal for the Suspend button.
*/